@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2015-11-24'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -180,11 +180,19 @@ sub format {
                 return __gen_table($data, 1, $res->[3], $format);
             } elsif (Data::Check::Structure::is_aohos($data, {max=>$max})) {
                 # collect all mentioned fields
-                my %fieldnames;
-                for my $row (@$data) {
-                    $fieldnames{$_}++ for keys %$row;
+                my @fieldnames;
+                my $hide_unknown_fields;
+                if ($res->[3] && $res->[3]{'table.fields'} &&
+                        $res->[3]{'table.hide_unknown_fields'}) {
+                    $hide_unknown_fields = 1;
+                    @fieldnames = @{ $res->[3]{'table.fields'} };
+                } else {
+                    my %fieldnames;
+                    for my $row (@$data) {
+                        $fieldnames{$_}++ for keys %$row;
+                    }
+                    my @fieldnames = sort keys %fieldnames;
                 }
-                my @fieldnames = sort keys %fieldnames;
                 my $newdata = [];
                 for my $row (@$data) {
                     push @$newdata, [map {$row->{$_}} @fieldnames];
@@ -197,16 +205,27 @@ sub format {
         }
     }
 
+    my $tff = $res->[3]{'table.fields'};
     $res = $res->[2] if $is_naked;
 
-    warn "Unknown format '$format', fallback to json-pretty"
-        unless $format =~ /\Ajson(-pretty)?\z/;
+    unless ($format =~ /\Ajson(-pretty)?\z/) {
+        warn "Unknown format '$format', fallback to json-pretty";
+        $format = 'json-pretty';
+    }
     __cleanse($res) if ($cleanse//1);
-    if ($format eq 'json') {
-        return _json->encode($res) . "\n";
-    } else {
-        _json->pretty(1);
-        return _json->encode($res);
+    if ($format =~ /json/) {
+        if ($tff && _json->can("sort_by") &&
+                eval { require Sort::ByExample; 1}) {
+            my $cmp = Sort::ByExample->cmp($tff);
+            _json->sort_by(sub { $cmp->($JSON::PP::a, $JSON::PP::b) });
+        }
+
+        if ($format eq 'json') {
+            return _json->encode($res) . "\n";
+        } else {
+            _json->pretty(1);
+            return _json->encode($res);
+        }
     }
 }
 
@@ -225,7 +244,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.09 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2015-11-24.
+This document describes version 0.10 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -273,7 +292,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
